import { Subject } from 'rxjs';
import { OptionViewBase } from '@/studio-core';
import HRArchivesService from '@/service/hrarchives/hrarchives-service';
import HRArchivesAuthService from '@/authservice/hrarchives/hrarchives-auth-service';
import OptionViewEngine from '@engine/view/option-view-engine';
import HRArchivesUIService from '@/uiservice/hrarchives/hrarchives-ui-service';

/**
 * 档案信息视图基类
 *
 * @export
 * @class HRArchivesV_002Base
 * @extends {OptionViewBase}
 */
export class HRArchivesV_002Base extends OptionViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_002Base
     */
    protected appDeName: string = 'hrarchives';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_002Base
     */
    protected appDeKey: string = 'hrarchivesid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_002Base
     */
    protected appDeMajor: string = 'hrarchivesname';

    /**
     * 实体服务对象
     *
     * @type {HRArchivesService}
     * @memberof HRArchivesV_002Base
     */
    protected appEntityService: HRArchivesService = new HRArchivesService;

    /**
     * 实体权限服务对象
     *
     * @type HRArchivesUIService
     * @memberof HRArchivesV_002Base
     */
    public appUIService: HRArchivesUIService = new HRArchivesUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HRArchivesV_002Base
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HRArchivesV_002Base
     */
    protected model: any = {
        srfCaption: 'entities.hrarchives.views.v_002.caption',
        srfTitle: 'entities.hrarchives.views.v_002.title',
        srfSubTitle: 'entities.hrarchives.views.v_002.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HRArchivesV_002Base
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '8bd2a4a14135c358985d4ff9b7ffb88e';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HRArchivesV_002Base
     */
    public engine: OptionViewEngine = new OptionViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HRArchivesV_002Base
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'hrarchives',
            majorPSDEField: 'hrarchivesname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRArchivesV_002Base
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRArchivesV_002Base
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HRArchivesV_002Base
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}