import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 职务技能服务对象基类
 *
 * @export
 * @class HRDutySkillServiceBase
 * @extends {EntityServie}
 */
export default class HRDutySkillServiceBase extends EntityService {

    /**
     * Creates an instance of  HRDutySkillServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  HRDutySkillServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof HRDutySkillServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='hrdutyskill';
        this.APPDEKEY = 'hrdutyskillid';
        this.APPDENAME = 'hrdutyskills';
        this.APPDETEXT = 'hrdutyskillname';
        this.APPNAME = 'pim';
        this.SYSTEMNAME = 'ibizhumanresources';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && context.hrdutyskill){
            let res:any = Http.getInstance().get(`/hrduties/${context.hrduty}/hrdutyskills/${context.hrdutyskill}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/hrdutyskills/${context.hrdutyskill}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/hrduties/${context.hrduty}/hrdutyskills`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/hrdutyskills`,data,isloading);
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && context.hrdutyskill){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/hrduties/${context.hrduty}/hrdutyskills/${context.hrdutyskill}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/hrdutyskills/${context.hrdutyskill}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && context.hrdutyskill){
            let res:any = Http.getInstance().delete(`/hrduties/${context.hrduty}/hrdutyskills/${context.hrdutyskill}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/hrdutyskills/${context.hrdutyskill}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && context.hrdutyskill){
            let res:any = await Http.getInstance().get(`/hrduties/${context.hrduty}/hrdutyskills/${context.hrdutyskill}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/hrdutyskills/${context.hrdutyskill}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && true){
            let res:any = await Http.getInstance().get(`/hrduties/${context.hrduty}/hrdutyskills/getdraft`,isloading);
            res.data.hrdutyskill = data.hrdutyskill;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/hrdutyskills/getdraft`,isloading);
        res.data.hrdutyskill = data.hrdutyskill;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && context.hrdutyskill){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hrduties/${context.hrduty}/hrdutyskills/${context.hrdutyskill}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/hrdutyskills/${context.hrdutyskill}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && context.hrdutyskill){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hrduties/${context.hrduty}/hrdutyskills/${context.hrdutyskill}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/hrdutyskills/${context.hrdutyskill}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRDutySkillServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrduty && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/hrduties/${context.hrduty}/hrdutyskills/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hrdutyskills/fetchdefault`,tempData,isloading);
        return res;
    }
}