import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 职位关系服务对象基类
 *
 * @export
 * @class HRPostRelServiceBase
 * @extends {EntityServie}
 */
export default class HRPostRelServiceBase extends EntityService {

    /**
     * Creates an instance of  HRPostRelServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  HRPostRelServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof HRPostRelServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='hrpostrel';
        this.APPDEKEY = 'hrpostrelid';
        this.APPDENAME = 'hrpostrels';
        this.APPDETEXT = 'hrpostrelname';
        this.APPNAME = 'pim';
        this.SYSTEMNAME = 'ibizhumanresources';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && context.hrpostrel){
            let res:any = Http.getInstance().get(`/hrposts/${context.hrpost}/hrpostrels/${context.hrpostrel}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/hrpostrels/${context.hrpostrel}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/hrposts/${context.hrpost}/hrpostrels`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/hrpostrels`,data,isloading);
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && context.hrpostrel){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/hrposts/${context.hrpost}/hrpostrels/${context.hrpostrel}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/hrpostrels/${context.hrpostrel}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && context.hrpostrel){
            let res:any = Http.getInstance().delete(`/hrposts/${context.hrpost}/hrpostrels/${context.hrpostrel}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/hrpostrels/${context.hrpostrel}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && context.hrpostrel){
            let res:any = await Http.getInstance().get(`/hrposts/${context.hrpost}/hrpostrels/${context.hrpostrel}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/hrpostrels/${context.hrpostrel}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && true){
            let res:any = await Http.getInstance().get(`/hrposts/${context.hrpost}/hrpostrels/getdraft`,isloading);
            res.data.hrpostrel = data.hrpostrel;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/hrpostrels/getdraft`,isloading);
        res.data.hrpostrel = data.hrpostrel;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && context.hrpostrel){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hrposts/${context.hrpost}/hrpostrels/${context.hrpostrel}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/hrpostrels/${context.hrpostrel}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && context.hrpostrel){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hrposts/${context.hrpost}/hrpostrels/${context.hrpostrel}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/hrpostrels/${context.hrpostrel}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRPostRelServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hrpost && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/hrposts/${context.hrpost}/hrpostrels/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hrpostrels/fetchdefault`,tempData,isloading);
        return res;
    }
}