package cn.ibizlab.humanresource.core.humanresource.service.impl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.Map;
import java.util.HashSet;
import java.util.HashMap;
import java.util.Collection;
import java.util.Objects;
import java.util.Optional;
import java.math.BigInteger;

import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.ObjectUtils;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.context.annotation.Lazy;
import cn.ibizlab.humanresource.core.humanresource.domain.HRArchivesMove;
import cn.ibizlab.humanresource.core.humanresource.filter.HRArchivesMoveSearchContext;
import cn.ibizlab.humanresource.core.humanresource.service.IHRArchivesMoveService;

import cn.ibizlab.humanresource.util.helper.CachedBeanCopier;
import cn.ibizlab.humanresource.util.helper.DEFieldCacheMap;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import cn.ibizlab.humanresource.core.humanresource.mapper.HRArchivesMoveMapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.alibaba.fastjson.JSONObject;
import org.springframework.util.StringUtils;

/**
 * 实体[档案调档] 服务对象接口实现
 */
@Slf4j
@Service("HRArchivesMoveServiceImpl")
public class HRArchivesMoveServiceImpl extends ServiceImpl<HRArchivesMoveMapper, HRArchivesMove> implements IHRArchivesMoveService {

    @Autowired
    @Lazy
    protected cn.ibizlab.humanresource.core.humanresource.service.IHRArchivesService hrarchivesService;

    protected int batchSize = 500;

    @Override
    @Transactional
    public boolean create(HRArchivesMove et) {
        if(!this.retBool(this.baseMapper.insert(et)))
            return false;
        CachedBeanCopier.copy(get(et.getHrarchivesmoveid()),et);
        return true;
    }

    @Override
    public void createBatch(List<HRArchivesMove> list) {
        this.saveBatch(list,batchSize);
    }

    @Override
    @Transactional
    public boolean update(HRArchivesMove et) {
        if(!update(et,(Wrapper) et.getUpdateWrapper(true).eq("hrarchivesmoveid",et.getHrarchivesmoveid())))
            return false;
        CachedBeanCopier.copy(get(et.getHrarchivesmoveid()),et);
        return true;
    }

    @Override
    public void updateBatch(List<HRArchivesMove> list) {
        updateBatchById(list,batchSize);
    }

    @Override
    @Transactional
    public boolean remove(String key) {
        boolean result=removeById(key);
        return result ;
    }

    @Override
    public void removeBatch(Collection<String> idList) {
        removeByIds(idList);
    }

    @Override
    @Transactional
    public HRArchivesMove get(String key) {
        HRArchivesMove et = getById(key);
        if(et==null){
            et=new HRArchivesMove();
            et.setHrarchivesmoveid(key);
        }
        else{
        }
        return et;
    }

    @Override
    public HRArchivesMove getDraft(HRArchivesMove et) {
        return et;
    }

    @Override
    public boolean checkKey(HRArchivesMove et) {
        return (!ObjectUtils.isEmpty(et.getHrarchivesmoveid()))&&(!Objects.isNull(this.getById(et.getHrarchivesmoveid())));
    }
    @Override
    @Transactional
    public boolean save(HRArchivesMove et) {
        if(!saveOrUpdate(et))
            return false;
        return true;
    }

    @Override
    @Transactional
    public boolean saveOrUpdate(HRArchivesMove et) {
        if (null == et) {
            return false;
        } else {
            return checkKey(et) ? this.update(et) : this.create(et);
        }
    }

    @Override
    public boolean saveBatch(Collection<HRArchivesMove> list) {
        saveOrUpdateBatch(list,batchSize);
        return true;
    }

    @Override
    public void saveBatch(List<HRArchivesMove> list) {
        saveOrUpdateBatch(list,batchSize);
    }


	@Override
    public List<HRArchivesMove> selectByHrarchivesid(String hrarchivesid) {
        return baseMapper.selectByHrarchivesid(hrarchivesid);
    }

    @Override
    public void removeByHrarchivesid(String hrarchivesid) {
        this.remove(new QueryWrapper<HRArchivesMove>().eq("hrarchivesid",hrarchivesid));
    }


    /**
     * 查询集合 DEFAULT
     */
    @Override
    public Page<HRArchivesMove> searchDefault(HRArchivesMoveSearchContext context) {
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<HRArchivesMove> pages=baseMapper.searchDefault(context.getPages(),context,context.getSelectCond());
        return new PageImpl<HRArchivesMove>(pages.getRecords(), context.getPageable(), pages.getTotal());
    }







    @Override
    public List<JSONObject> select(String sql, Map param){
        return this.baseMapper.selectBySQL(sql,param);
    }

    @Override
    @Transactional
    public boolean execute(String sql , Map param){
        if (sql == null || sql.isEmpty()) {
            return false;
        }
        if (sql.toLowerCase().trim().startsWith("insert")) {
            return this.baseMapper.insertBySQL(sql,param);
        }
        if (sql.toLowerCase().trim().startsWith("update")) {
            return this.baseMapper.updateBySQL(sql,param);
        }
        if (sql.toLowerCase().trim().startsWith("delete")) {
            return this.baseMapper.deleteBySQL(sql,param);
        }
        log.warn("暂未支持的SQL语法");
        return true;
    }

    @Override
    public List<HRArchivesMove> getHrarchivesmoveByIds(List<String> ids) {
         return this.listByIds(ids);
    }

    @Override
    public List<HRArchivesMove> getHrarchivesmoveByEntities(List<HRArchivesMove> entities) {
        List ids =new ArrayList();
        for(HRArchivesMove entity : entities){
            Serializable id=entity.getHrarchivesmoveid();
            if(!ObjectUtils.isEmpty(id)){
                ids.add(id);
            }
        }
        if(ids.size()>0)
           return this.listByIds(ids);
        else
           return entities;
    }

}



