package cn.ibizlab.humanresource.core.humanresource.service.impl;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.Map;
import java.util.HashSet;
import java.util.HashMap;
import java.util.Collection;
import java.util.Objects;
import java.util.Optional;
import java.math.BigInteger;

import lombok.extern.slf4j.Slf4j;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.stereotype.Service;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.ObjectUtils;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.context.annotation.Lazy;
import cn.ibizlab.humanresource.core.humanresource.domain.HRCertificate;
import cn.ibizlab.humanresource.core.humanresource.filter.HRCertificateSearchContext;
import cn.ibizlab.humanresource.core.humanresource.service.IHRCertificateService;

import cn.ibizlab.humanresource.util.helper.CachedBeanCopier;
import cn.ibizlab.humanresource.util.helper.DEFieldCacheMap;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import cn.ibizlab.humanresource.core.humanresource.mapper.HRCertificateMapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.alibaba.fastjson.JSONObject;
import org.springframework.util.StringUtils;

/**
 * 实体[证书信息] 服务对象接口实现
 */
@Slf4j
@Service("HRCertificateServiceImpl")
public class HRCertificateServiceImpl extends ServiceImpl<HRCertificateMapper, HRCertificate> implements IHRCertificateService {

    @Autowired
    @Lazy
    protected cn.ibizlab.humanresource.core.humanresource.service.IHREmployeeService hremployeeService;
    @Autowired
    @Lazy
    protected cn.ibizlab.humanresource.core.base.service.IHROrganizationService hrorganizationService;

    protected int batchSize = 500;

    @Override
    @Transactional
    public boolean create(HRCertificate et) {
        fillParentData(et);
        if(!this.retBool(this.baseMapper.insert(et)))
            return false;
        CachedBeanCopier.copy(get(et.getHrcertificateid()),et);
        return true;
    }

    @Override
    public void createBatch(List<HRCertificate> list) {
        list.forEach(item->fillParentData(item));
        this.saveBatch(list,batchSize);
    }

    @Override
    @Transactional
    public boolean update(HRCertificate et) {
        fillParentData(et);
        if(!update(et,(Wrapper) et.getUpdateWrapper(true).eq("hrcertificateid",et.getHrcertificateid())))
            return false;
        CachedBeanCopier.copy(get(et.getHrcertificateid()),et);
        return true;
    }

    @Override
    public void updateBatch(List<HRCertificate> list) {
        list.forEach(item->fillParentData(item));
        updateBatchById(list,batchSize);
    }

    @Override
    @Transactional
    public boolean remove(String key) {
        boolean result=removeById(key);
        return result ;
    }

    @Override
    public void removeBatch(Collection<String> idList) {
        removeByIds(idList);
    }

    @Override
    @Transactional
    public HRCertificate get(String key) {
        HRCertificate et = getById(key);
        if(et==null){
            et=new HRCertificate();
            et.setHrcertificateid(key);
        }
        else{
        }
        return et;
    }

    @Override
    public HRCertificate getDraft(HRCertificate et) {
        fillParentData(et);
        return et;
    }

    @Override
    public boolean checkKey(HRCertificate et) {
        return (!ObjectUtils.isEmpty(et.getHrcertificateid()))&&(!Objects.isNull(this.getById(et.getHrcertificateid())));
    }
    @Override
    @Transactional
    public boolean save(HRCertificate et) {
        if(!saveOrUpdate(et))
            return false;
        return true;
    }

    @Override
    @Transactional
    public boolean saveOrUpdate(HRCertificate et) {
        if (null == et) {
            return false;
        } else {
            return checkKey(et) ? this.update(et) : this.create(et);
        }
    }

    @Override
    public boolean saveBatch(Collection<HRCertificate> list) {
        list.forEach(item->fillParentData(item));
        saveOrUpdateBatch(list,batchSize);
        return true;
    }

    @Override
    public void saveBatch(List<HRCertificate> list) {
        list.forEach(item->fillParentData(item));
        saveOrUpdateBatch(list,batchSize);
    }


	@Override
    public List<HRCertificate> selectByHremployeeid(String employeeid) {
        return baseMapper.selectByHremployeeid(employeeid);
    }

    @Override
    public void removeByHremployeeid(String employeeid) {
        this.remove(new QueryWrapper<HRCertificate>().eq("hremployeeid",employeeid));
    }

	@Override
    public List<HRCertificate> selectByRegisterorganizationid(String organizationid) {
        return baseMapper.selectByRegisterorganizationid(organizationid);
    }

    @Override
    public void removeByRegisterorganizationid(String organizationid) {
        this.remove(new QueryWrapper<HRCertificate>().eq("registerorganizationid",organizationid));
    }


    /**
     * 查询集合 有效证书
     */
    @Override
    public Page<HRCertificate> searchActive(HRCertificateSearchContext context) {
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<HRCertificate> pages=baseMapper.searchActive(context.getPages(),context,context.getSelectCond());
        return new PageImpl<HRCertificate>(pages.getRecords(), context.getPageable(), pages.getTotal());
    }

    /**
     * 查询集合 DEFAULT
     */
    @Override
    public Page<HRCertificate> searchDefault(HRCertificateSearchContext context) {
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<HRCertificate> pages=baseMapper.searchDefault(context.getPages(),context,context.getSelectCond());
        return new PageImpl<HRCertificate>(pages.getRecords(), context.getPageable(), pages.getTotal());
    }

    /**
     * 查询集合 有效证书
     */
    @Override
    public Page<HRCertificate> searchInActive(HRCertificateSearchContext context) {
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<HRCertificate> pages=baseMapper.searchInActive(context.getPages(),context,context.getSelectCond());
        return new PageImpl<HRCertificate>(pages.getRecords(), context.getPageable(), pages.getTotal());
    }

    /**
     * 查询集合 即将过期
     */
    @Override
    public Page<HRCertificate> searchSoonExpired(HRCertificateSearchContext context) {
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<HRCertificate> pages=baseMapper.searchSoonExpired(context.getPages(),context,context.getSelectCond());
        return new PageImpl<HRCertificate>(pages.getRecords(), context.getPageable(), pages.getTotal());
    }



    /**
     * 为当前实体填充父数据（外键值文本、外键值附加数据）
     * @param et
     */
    private void fillParentData(HRCertificate et){
        //实体关系[DER1N_HRCERTIFICATE_HREMPLOYEE_HREMPLOYEEID_327A4D]
        if(!ObjectUtils.isEmpty(et.getHremployeeid())){
            cn.ibizlab.humanresource.core.humanresource.domain.HREmployee hremployee=et.getHremployee();
            if(ObjectUtils.isEmpty(hremployee)){
                cn.ibizlab.humanresource.core.humanresource.domain.HREmployee majorEntity=hremployeeService.get(et.getHremployeeid());
                et.setHremployee(majorEntity);
                hremployee=majorEntity;
            }
            et.setHremployeename(hremployee.getEmployeename());
            et.setEmployeecode(hremployee.getEmployeecode());
            et.setOrganizationname(hremployee.getOrganizationname());
            et.setOrganizationid(hremployee.getOrganizationid());
            et.setEmpstate(hremployee.getEmpstate());
        }
        //实体关系[DER1N_HRCERTIFICATE_HRORGANIZATION_REGISTERORGANIZATIONID_6BD9DC]
        if(!ObjectUtils.isEmpty(et.getRegisterorganizationid())){
            cn.ibizlab.humanresource.core.base.domain.HROrganization registerorganization=et.getRegisterorganization();
            if(ObjectUtils.isEmpty(registerorganization)){
                cn.ibizlab.humanresource.core.base.domain.HROrganization majorEntity=hrorganizationService.get(et.getRegisterorganizationid());
                et.setRegisterorganization(majorEntity);
                registerorganization=majorEntity;
            }
            et.setRegisterorganizationname(registerorganization.getOrganizationname());
        }
    }




    @Override
    public List<JSONObject> select(String sql, Map param){
        return this.baseMapper.selectBySQL(sql,param);
    }

    @Override
    @Transactional
    public boolean execute(String sql , Map param){
        if (sql == null || sql.isEmpty()) {
            return false;
        }
        if (sql.toLowerCase().trim().startsWith("insert")) {
            return this.baseMapper.insertBySQL(sql,param);
        }
        if (sql.toLowerCase().trim().startsWith("update")) {
            return this.baseMapper.updateBySQL(sql,param);
        }
        if (sql.toLowerCase().trim().startsWith("delete")) {
            return this.baseMapper.deleteBySQL(sql,param);
        }
        log.warn("暂未支持的SQL语法");
        return true;
    }

    @Override
    public List<HRCertificate> getHrcertificateByIds(List<String> ids) {
         return this.listByIds(ids);
    }

    @Override
    public List<HRCertificate> getHrcertificateByEntities(List<HRCertificate> entities) {
        List ids =new ArrayList();
        for(HRCertificate entity : entities){
            Serializable id=entity.getHrcertificateid();
            if(!ObjectUtils.isEmpty(id)){
                ids.add(id);
            }
        }
        if(ids.size()>0)
           return this.listByIds(ids);
        else
           return entities;
    }

}



