package cn.ibizlab.humanresource.hrapi.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.access.prepost.PostAuthorize;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import cn.ibizlab.humanresource.hrapi.dto.*;
import cn.ibizlab.humanresource.hrapi.mapping.*;
import cn.ibizlab.humanresource.core.base.domain.HRLegal;
import cn.ibizlab.humanresource.core.base.service.IHRLegalService;
import cn.ibizlab.humanresource.core.base.filter.HRLegalSearchContext;
import cn.ibizlab.humanresource.util.annotation.VersionCheck;

@Slf4j
@Api(tags = {"法人" })
@RestController("HRApi-hrlegal")
@RequestMapping("")
public class HRLegalResource {

    @Autowired
    public IHRLegalService hrlegalService;

    @Autowired
    @Lazy
    public HRLegalMapping hrlegalMapping;

    @PreAuthorize("hasPermission(this.hrlegalMapping.toDomain(#hrlegaldto),'iBizHumanResources-HRLegal-Create')")
    @ApiOperation(value = "新建法人", tags = {"法人" },  notes = "新建法人")
	@RequestMapping(method = RequestMethod.POST, value = "/hrlegals")
    @Transactional
    public ResponseEntity<HRLegalDTO> create(@RequestBody HRLegalDTO hrlegaldto) {
        HRLegal domain = hrlegalMapping.toDomain(hrlegaldto);
		hrlegalService.create(domain);
        HRLegalDTO dto = hrlegalMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.hrlegalMapping.toDomain(#hrlegaldtos),'iBizHumanResources-HRLegal-Create')")
    @ApiOperation(value = "批量新建法人", tags = {"法人" },  notes = "批量新建法人")
	@RequestMapping(method = RequestMethod.POST, value = "/hrlegals/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<HRLegalDTO> hrlegaldtos) {
        hrlegalService.createBatch(hrlegalMapping.toDomain(hrlegaldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @VersionCheck(entity = "hrlegal" , versionfield = "updatedate")
    @PreAuthorize("hasPermission(this.hrlegalService.get(#hrlegal_id),'iBizHumanResources-HRLegal-Update')")
    @ApiOperation(value = "更新法人", tags = {"法人" },  notes = "更新法人")
	@RequestMapping(method = RequestMethod.PUT, value = "/hrlegals/{hrlegal_id}")
    @Transactional
    public ResponseEntity<HRLegalDTO> update(@PathVariable("hrlegal_id") String hrlegal_id, @RequestBody HRLegalDTO hrlegaldto) {
		HRLegal domain  = hrlegalMapping.toDomain(hrlegaldto);
        domain .setLegalid(hrlegal_id);
		hrlegalService.update(domain );
		HRLegalDTO dto = hrlegalMapping.toDto(domain );
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasPermission(this.hrlegalService.getHrlegalByEntities(this.hrlegalMapping.toDomain(#hrlegaldtos)),'iBizHumanResources-HRLegal-Update')")
    @ApiOperation(value = "批量更新法人", tags = {"法人" },  notes = "批量更新法人")
	@RequestMapping(method = RequestMethod.PUT, value = "/hrlegals/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<HRLegalDTO> hrlegaldtos) {
        hrlegalService.updateBatch(hrlegalMapping.toDomain(hrlegaldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasPermission(this.hrlegalService.get(#hrlegal_id),'iBizHumanResources-HRLegal-Remove')")
    @ApiOperation(value = "删除法人", tags = {"法人" },  notes = "删除法人")
	@RequestMapping(method = RequestMethod.DELETE, value = "/hrlegals/{hrlegal_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("hrlegal_id") String hrlegal_id) {
         return ResponseEntity.status(HttpStatus.OK).body(hrlegalService.remove(hrlegal_id));
    }

    @PreAuthorize("hasPermission(this.hrlegalService.getHrlegalByIds(#ids),'iBizHumanResources-HRLegal-Remove')")
    @ApiOperation(value = "批量删除法人", tags = {"法人" },  notes = "批量删除法人")
	@RequestMapping(method = RequestMethod.DELETE, value = "/hrlegals/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        hrlegalService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PostAuthorize("hasPermission(this.hrlegalMapping.toDomain(returnObject.body),'iBizHumanResources-HRLegal-Get')")
    @ApiOperation(value = "获取法人", tags = {"法人" },  notes = "获取法人")
	@RequestMapping(method = RequestMethod.GET, value = "/hrlegals/{hrlegal_id}")
    public ResponseEntity<HRLegalDTO> get(@PathVariable("hrlegal_id") String hrlegal_id) {
        HRLegal domain = hrlegalService.get(hrlegal_id);
        HRLegalDTO dto = hrlegalMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "获取法人草稿", tags = {"法人" },  notes = "获取法人草稿")
	@RequestMapping(method = RequestMethod.GET, value = "/hrlegals/getdraft")
    public ResponseEntity<HRLegalDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(hrlegalMapping.toDto(hrlegalService.getDraft(new HRLegal())));
    }

    @ApiOperation(value = "检查法人", tags = {"法人" },  notes = "检查法人")
	@RequestMapping(method = RequestMethod.POST, value = "/hrlegals/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody HRLegalDTO hrlegaldto) {
        return  ResponseEntity.status(HttpStatus.OK).body(hrlegalService.checkKey(hrlegalMapping.toDomain(hrlegaldto)));
    }

    @PreAuthorize("hasPermission(this.hrlegalMapping.toDomain(#hrlegaldto),'iBizHumanResources-HRLegal-Save')")
    @ApiOperation(value = "保存法人", tags = {"法人" },  notes = "保存法人")
	@RequestMapping(method = RequestMethod.POST, value = "/hrlegals/save")
    public ResponseEntity<Boolean> save(@RequestBody HRLegalDTO hrlegaldto) {
        return ResponseEntity.status(HttpStatus.OK).body(hrlegalService.save(hrlegalMapping.toDomain(hrlegaldto)));
    }

    @PreAuthorize("hasPermission(this.hrlegalMapping.toDomain(#hrlegaldtos),'iBizHumanResources-HRLegal-Save')")
    @ApiOperation(value = "批量保存法人", tags = {"法人" },  notes = "批量保存法人")
	@RequestMapping(method = RequestMethod.POST, value = "/hrlegals/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<HRLegalDTO> hrlegaldtos) {
        hrlegalService.saveBatch(hrlegalMapping.toDomain(hrlegaldtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','iBizHumanResources-HRLegal-searchDefault-all') and hasPermission(#context,'iBizHumanResources-HRLegal-Get')")
	@ApiOperation(value = "获取DEFAULT", tags = {"法人" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/hrlegals/fetchdefault")
	public ResponseEntity<List<HRLegalDTO>> fetchDefault(HRLegalSearchContext context) {
        Page<HRLegal> domains = hrlegalService.searchDefault(context) ;
        List<HRLegalDTO> list = hrlegalMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','iBizHumanResources-HRLegal-searchDefault-all') and hasPermission(#context,'iBizHumanResources-HRLegal-Get')")
	@ApiOperation(value = "查询DEFAULT", tags = {"法人" } ,notes = "查询DEFAULT")
    @RequestMapping(method= RequestMethod.POST , value="/hrlegals/searchdefault")
	public ResponseEntity<Page<HRLegalDTO>> searchDefault(@RequestBody HRLegalSearchContext context) {
        Page<HRLegal> domains = hrlegalService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(hrlegalMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}
}

